@@ -25,6 +25,7 @@ from pydantic_openapi_schema.v3_1_0.reference import Reference
 from pydantic_openapi_schema.v3_1_0.security_requirement import SecurityRequirement
 from pydantic_openapi_schema.v3_1_0.server import Server
 from pydantic_openapi_schema.v3_1_0.tag import Tag
+from starlette.staticfiles import StaticFiles
 from typing_extensions import Literal
 
 from starlite.cache import CacheBackendProtocol, SimpleCacheBackend
@@ -33,8 +34,11 @@ from starlite.openapi.path_item import create_path_item
 from starlite.routes import HTTPRoute
 from starlite.template import TemplateEngineProtocol
 from starlite.types import CacheKeyBuilder, Method
+from starlite.utils import normalize_path
 
 if TYPE_CHECKING:
+    from starlette.types import ASGIApp
+
     from starlite.app import Starlite
     from starlite.connection import Request
 
@@ -284,6 +288,36 @@ class StaticFilesConfig(BaseModel):
     directories: List[DirectoryPath]
     html_mode: bool = False
 
+    @validator("path")
+    def validate_path(cls, value: str) -> str:  # pylint: disable=no-self-argument
+        """
+        Ensures the the path has not path parameters
+
+        Args:
+            value: A path string
+
+        Returns:
+            The passed in value
+        """
+        if "{" in value:
+            raise ValueError("path parameters are not supported for static files")
+        return normalize_path(value)
+
+    def to_static_files_app(self) -> "ASGIApp":
+        """
+                Returns an ASGI app serving static files based on the config
+
+                Returns:
+        ^           [StaticFiles][starlette.static_files.StaticFiles]
+        """
+        static_files = StaticFiles(
+            html=self.html_mode,
+            check_dir=False,
+            directory=str(self.directories[0]),
+        )
+        static_files.all_directories = self.directories  # type: ignore[assignment]
+        return static_files
+
 
 class TemplateConfig(BaseModel):
     class Config(BaseConfig):
